@@ -3,6 +3,7 @@ import re
 from collections import defaultdict
 from typing import DefaultDict, List, Optional, Tuple, Union
 
+import aiohttp
 import arrow
 from diskcache import Cache
 from nonebot.adapters.onebot.v11 import (
@@ -13,6 +14,7 @@ from nonebot.adapters.onebot.v11 import (
     MessageEvent,
     PrivateMessageEvent,
 )
+from nonebot.log import logger
 from nonebot.matcher import Matcher
 from nonebot.params import CommandArg
 from nonebot.plugin.on import on_command, on_message
@@ -73,34 +75,39 @@ async def image_search(
     proxy: Optional[str] = config.proxy,
     hide_img: bool = config.hide_img,
 ) -> List[str]:
-    url = get_universal_img_url(url)
-    image_md5 = re.search("[A-F0-9]{32}", url)[0]  # type: ignore
+    url = await get_universal_img_url(url)
+    image_md5 = re.search(r"[A-F\d]{32}", url)[0]  # type: ignore
     if not purge and (result := exist_in_cache(_cache, image_md5, mode)):
         return [f"[缓存] {i}" for i in result]
-    else:
-        try:
-            if mode == "a2d":
-                result = await ascii2d_search(url, proxy, hide_img)
-            elif mode == "iqdb":
-                result = await iqdb_search(url, proxy, hide_img)
-            elif mode == "ex":
-                result = await ehentai_search(url, proxy, hide_img)
-            else:
-                result = await saucenao_search(url, mode, proxy, hide_img)
-        except Exception as e:
-            thumbnail = await handle_img(url, proxy, False)
-            return [f"{thumbnail}\n❌️ 该图搜图失败，请稍后再试\nE: {repr(e)}"]
-        upsert_cache(_cache, image_md5, mode, result)
-        return result
+    try:
+        if mode == "a2d":
+            result = await ascii2d_search(url, proxy, hide_img)
+        elif mode == "iqdb":
+            result = await iqdb_search(url, proxy, hide_img)
+        elif mode == "ex":
+            result = await ehentai_search(url, proxy, hide_img)
+        else:
+            result = await saucenao_search(url, mode, proxy, hide_img)
+    except Exception as e:
+        thumbnail = await handle_img(url, proxy, False)
+        logger.error(f"❌️ 该图 [{url}] 搜图失败")
+        logger.exception(e)
+        return [f"{thumbnail}\n❌️ 该图搜图失败\nE: {repr(e)}"]
+    upsert_cache(_cache, image_md5, mode, result)
+    return result
 
 
-def get_universal_img_url(url: str) -> str:
+async def get_universal_img_url(url: str) -> str:
     fianl_url = url.replace(
         "/c2cpicdw.qpic.cn/offpic_new/", "/gchat.qpic.cn/gchatpic_new/"
     )
     final_url = re.sub(r"/\d+/+\d+-\d+-", "/0/0-0-", fianl_url)
     final_url = re.sub(r"\?.*$", "", final_url)
-    return final_url
+    async with aiohttp.ClientSession() as session:
+        async with session.get(final_url) as resp:
+            if resp.status == 200:
+                return final_url
+    return url
 
 
 def get_image_urls(event: MessageEvent) -> List[str]:
@@ -124,46 +131,47 @@ def get_args(msg: Message) -> Tuple[str, bool]:
 async def send_result_message(
     bot: Bot, event: MessageEvent, msg_list: List[str]
 ) -> None:
-    if isinstance(event, PrivateMessageEvent):
-        for msg in msg_list:
+    if isinstance(event, GroupMessageEvent):
+        current_sending_lock = sending_lock[(event.group_id, "group")]
+    else:
+        current_sending_lock = sending_lock[(event.user_id, "private")]
+    if flag := (config.forward_search_result and len(msg_list) > 1):
+        try:
             start_time = arrow.now()
-            async with sending_lock[(event.user_id, "private")]:
-                await bot.send_private_msg(user_id=event.user_id, message=msg)
+            async with current_sending_lock:
+                await send_forward_msg(bot, event, msg_list)
+                await asyncio.sleep(
+                    max(1 - (arrow.now() - start_time).total_seconds(), 0)
+                )
+        except ActionFailed:
+            flag = False
+    if not flag:
+        for msg in msg_list:
+            start_time = arrow.now()
+            async with current_sending_lock:
+                await send_msg(bot, event, msg)
                 await asyncio.sleep(
                     max(1 - (arrow.now() - start_time).total_seconds(), 0)
                 )
-    elif isinstance(event, GroupMessageEvent):
-        flag = config.group_forward_search_result and len(msg_list) > 1
-        if flag:
-            try:
-                start_time = arrow.now()
-                async with sending_lock[(event.group_id, "group")]:
-                    await send_group_forward_msg(bot, event, msg_list)
-                    await asyncio.sleep(
-                        max(1 - (arrow.now() - start_time).total_seconds(), 0)
-                    )
-            except ActionFailed:
-                flag = False
-        if not flag:
-            for msg in msg_list:
-                start_time = arrow.now()
-                async with sending_lock[(event.group_id, "group")]:
-                    await bot.send_group_msg(group_id=event.group_id, message=msg)
-                    await asyncio.sleep(
-                        max(1 - (arrow.now() - start_time).total_seconds(), 0)
-                    )
 
 
-async def send_group_forward_msg(
-    bot: Bot, event: GroupMessageEvent, msg_list: List[str]
-) -> None:
-    await bot.send_group_forward_msg(
-        group_id=event.group_id,
+async def send_msg(bot: Bot, event: MessageEvent, message: str) -> None:
+    await bot.send_msg(
+        user_id=event.user_id if isinstance(event, PrivateMessageEvent) else 0,
+        group_id=event.group_id if isinstance(event, GroupMessageEvent) else 0,
+        message=message,
+    )
+
+
+async def send_forward_msg(bot: Bot, event: MessageEvent, msg_list: List[str]) -> None:
+    await bot.send_forward_msg(
+        user_id=event.user_id if isinstance(event, PrivateMessageEvent) else 0,
+        group_id=event.group_id if isinstance(event, GroupMessageEvent) else 0,
         messages=[
             {
                 "type": "node",
                 "data": {
-                    "name": "\u200b",
+                    "name": config.nickname[0] if config.nickname else "\u200b",
                     "uin": bot.self_id,
                     "content": msg,
                 },
